@@ -2,7 +2,7 @@
 /**
  * Turba delete.php.
  *
- * Copyright 2000-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2000-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -30,9 +30,11 @@ try {
 try {
     $driver->delete($vars->key);
     $notification->push(sprintf(_("Deleted contact: %s"), $object->getValue('name')), 'horde.success');
-    $url = strlen($vars->url)
-        ? new Horde_Url($vars->url)
-        : Horde::url($prefs->getValue('initial_page'), true);
+    if ($url = Horde::verifySignedUrl($vars->url)) {
+        $url = new Horde_Url($url);
+    } else {
+        $url = Horde::url($prefs->getValue('initial_page'), true);
+    }
     $url->redirect();
 } catch (Turba_Exception $e) {
     $notification->push(sprintf(_("There was an error deleting this contact: %s"), $e->getMessage()), 'horde.error');
