@@ -5,7 +5,7 @@
  * This file defines Turba's external API interface. Other applications can
  * interact with Turba through this API.
  *
- * Copyright 2009-2016 Horde LLC (http://www.horde.org/)
+ * Copyright 2009-2017 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file LICENSE for license information (ASL).  If you did
  * did not receive this file, see http://www.horde.org/licenses/apache.
@@ -2171,7 +2171,7 @@ class Turba_Api extends Horde_Registry_Api
     }
 
     /**
-     * Create a new addressbook
+     * Creates a new addressbook.
      *
      * @param string $name   The display name for the addressbook.
      * @param array  $params Any addtional parameters needed.
@@ -2185,16 +2185,27 @@ class Turba_Api extends Horde_Registry_Api
      */
     public function addAddressbook($name, array $params = array())
     {
-        $share_name = strval(new Horde_Support_Randomid());
-        $share = Turba::createShare($share_name, array('name' => $name));
-        $name = $share->getName();
+        global $conf, $injector, $prefs;
+
+        $cfgSources = Turba::availableSources();
+        $driver = $injector->getInstance('Turba_Factory_Driver')
+            ->create($cfgSources[$conf['shares']['source']]);
+        $share = $driver->createShare(
+            strval(new Horde_Support_Randomid()),
+            array(
+                'params' => array('source' => $conf['shares']['source']),
+                'name' => $name
+            )
+        );
+        $shareName = $share->getName();
+
         if (!empty($params['synchronize'])) {
             $sync = @unserialize($prefs->getValue('sync_books'));
-            $sync[] = $name;
+            $sync[] = $shareName;
             $prefs->setValue('sync_books', serialize($sync));
         }
 
-        return $name;
+        return $shareName;
     }
 
     /**
