@@ -1,5 +1,6 @@
 <?php if ($this->hasShare): ?>
 <div id="vbook-form"<?php echo $this->shareSources[$this->source] ? '' : ' style="display:none"' ?>>
+  <input type="hidden" name="token" value="<?php echo $this->token ?>" />
   <input type="checkbox" id="save-vbook" name="save_vbook" />
   <strong><label for="save-vbook"><?php echo _("Save search as a virtual address book?") ?></label></strong>
 
@@ -7,5 +8,4 @@
   <input type="text" id="vbook_name" name="vbook_name" />
 </div>
 <?php endif; ?>
-</form>
 <br />
